# Retroperm
A platform-agnostic retroactive effective permission generation system for compiled executables built using angr

## Developer Install
```sh 
git clone git@github.com:SpiritSeal/retroperm.git
cd retroperm
pip3 install -e .
```
